<?php
/**
 * SecondLine Theme Customizer
 *
 * @package slt
 */

get_template_part('inc/customizer/new', 'controls');


/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function secondline_themes_customize_preview_js() {
	wp_enqueue_script( 'secondline_themes_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'secondline_themes_customize_preview_js' );


function secondline_themes_customizer( $wp_customize ) {


	/* Panel - General */
	$wp_customize->add_panel( 'secondline_themes_general_panel', array(
		'priority'    => 3,
		'title'       => esc_html__( 'General', 'podcaster-secondline' ),
		 )
 	);


	/* Section - General - General Layout */
	$wp_customize->add_section( 'secondline_themes_section_general_layout', array(
		'title'          => esc_html__( 'General Options', 'podcaster-secondline' ),
		'panel'          => 'secondline_themes_general_panel', // Not typically needed.
		'priority'       => 10,
		)
	);


	/* Panel - Header */
	$wp_customize->add_panel( 'secondline_themes_header_panel', array(
		'priority'    => 5,
		'title'       => esc_html__( 'Header', 'podcaster-secondline' ),
		)
	);



	/* Section - Header - Fixed Header */
	$wp_customize->add_section( 'secondline_themes_section_options_nav', array(
		'title'          => esc_html__( 'Navigation Options', 'podcaster-secondline' ),
		'panel'          => 'secondline_themes_header_panel', // Not typically needed.
		'priority'       => 25,
		)
	);

	/* Setting - Header - Navigation */
	$wp_customize->add_setting('secondline_themes_nav_font_size',array(
		'default' => '15',
		'sanitize_callback' => 'secondline_themes_sanitize_choices',
	) );
	$wp_customize->add_control( new secondline_themes_Controls_Slider_Control($wp_customize, 'secondline_themes_nav_font_size', array(
		'label'    => esc_html__( 'Navigation Font Size', 'podcaster-secondline' ),
		'section'  => 'secondline_themes_section_options_nav',
		'priority'   => 500,
		'choices'     => array(
			'min'  => 0,
			'max'  => 30,
			'step' => 1
		), ) )
	);


	/* Setting - Header - Navigation */
	$wp_customize->add_setting('secondline_themes_nav_padding',array(
		'default' => '35',
		'sanitize_callback' => 'secondline_themes_sanitize_choices',
	) );
	$wp_customize->add_control( new secondline_themes_Controls_Slider_Control($wp_customize, 'secondline_themes_nav_padding', array(
		'label'    => esc_html__( 'Navigation Padding Top/Bottom', 'podcaster-secondline' ),
		'section'  => 'secondline_themes_section_options_nav',
		'priority'   => 505,
		'choices'     => array(
			'min'  => 5,
			'max'  => 100,
			'step' => 1
		), ) )
	);

	/* Setting - Header - Navigation */
	$wp_customize->add_setting('secondline_themes_nav_left_right',array(
		'default' => '18',
		'sanitize_callback' => 'secondline_themes_sanitize_choices',
	) );
	$wp_customize->add_control( new secondline_themes_Controls_Slider_Control($wp_customize, 'secondline_themes_nav_left_right', array(
		'label'    => esc_html__( 'Navigation Padding Left/Right', 'podcaster-secondline' ),
		'section'  => 'secondline_themes_section_options_nav',
		'priority'   => 510,
		'choices'     => array(
			'min'  => 8,
			'max'  => 80,
			'step' => 1
		), ) )
	);



	/* Setting - Header - Navigation */
	$wp_customize->add_setting('secondline_themes_sub_nav_font_size',array(
		'default' => '13',
		'sanitize_callback' => 'secondline_themes_sanitize_choices',
	) );
	$wp_customize->add_control( new secondline_themes_Controls_Slider_Control($wp_customize, 'secondline_themes_sub_nav_font_size', array(
		'label'    => esc_html__( 'Sub-Navigation Font Size', 'podcaster-secondline' ),
		'section'  => 'secondline_themes_section_options_nav',
		'priority'   => 510,
		'choices'     => array(
			'min'  => 0,
			'max'  => 30,
			'step' => 1
		), ) )
	);



	/* Panel - Body */
	$wp_customize->add_panel( 'secondline_themes_body_panel', array(
		'priority'    => 8,
        'title'       => esc_html__( 'Body', 'podcaster-secondline' ),
    ) );


	/* Section - Header - Fixed Header */
	$wp_customize->add_section( 'secondline_themes_section_page_title', array(
		'title'          => esc_html__( 'Page Title Options', 'podcaster-secondline' ),
		'panel'          => 'secondline_themes_body_panel', // Not typically needed.
		'priority'       => 25,
		)
	);


	/* Setting - General - Page Title */
	$wp_customize->add_setting( 'secondline_themes_page_title_bg_image' ,array(
		'default' => get_template_directory_uri().'/images/page-title.jpg',
		'sanitize_callback' => 'esc_url_raw',
	) );
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'secondline_themes_page_title_bg_image', array(
		'label'    => esc_html__( 'Page Title Background Image', 'podcaster-secondline' ),
		'section' => 'secondline_themes_section_page_title',
		'priority'   => 535,
		))
	);


	/* Setting - General - Page Title */
	$wp_customize->add_setting( 'secondline_themes_page_title_image_position' ,array(
		'default' => 'cover',
		'sanitize_callback' => 'secondline_themes_sanitize_choices',
	) );
	$wp_customize->add_control(new secondline_themes_Controls_Radio_Buttonset_Control($wp_customize, 'secondline_themes_page_title_image_position', array(
		'section' => 'secondline_themes_section_page_title',
		'priority'   => 536,
		'choices'     => array(
			'cover' => esc_html__( 'Image Cover', 'podcaster-secondline' ),
			'repeat-all' => esc_html__( 'Image Pattern', 'podcaster-secondline' ),
		),
		))
	);



		/* Panel - Body */
	$wp_customize->add_panel( 'secondline_themes_blog_panel', array(
		'priority'    => 8,
        'title'       => esc_html__( 'Blog', 'podcaster-secondline' ),
    ) );


	/* Section - Blog - Blog Index Post Options */
   $wp_customize->add_section( 'secondline_themes_section_blog_index', array(
   	'title'          => esc_html__( 'Post Archive Options', 'podcaster-secondline' ),
   	'panel'          => 'secondline_themes_blog_panel', // Not typically needed.
   	'priority'       => 20,
   )
	);


   /* Section - Blog - Blog Index Post Options */
	$wp_customize->add_setting( 'secondline_themes_blog_cat_sidebar' ,array(
		'default' => 'right-sidebar',
		'sanitize_callback' => 'secondline_themes_sanitize_choices',
	) );
	$wp_customize->add_control(new secondline_themes_Controls_Radio_Buttonset_Control($wp_customize, 'secondline_themes_blog_cat_sidebar', array(
		'label'    => esc_html__( 'Category Sidebar', 'podcaster-secondline' ),
		'section' => 'secondline_themes_section_blog_index',
		'priority'   => 70,
		'choices' => array(
			'left-sidebar' => esc_html__( 'Left', 'podcaster-secondline' ),
			'right-sidebar' => esc_html__( 'Right', 'podcaster-secondline' ),
			'no-sidebar' => esc_html__( 'Hidden', 'podcaster-secondline' ),

		 ),
		))
	);


   /* Section - Blog - Blog Index Post Options */
	$wp_customize->add_setting('secondline_themes_blog_columns',array(
		'default' => '2',
		'sanitize_callback' => 'secondline_themes_sanitize_choices',
	) );
	$wp_customize->add_control( new secondline_themes_Controls_Slider_Control($wp_customize, 'secondline_themes_blog_columns', array(
		'label'    => esc_html__( 'Post Columns', 'podcaster-secondline' ),
		'section' => 'secondline_themes_section_blog_index',
		'priority'   => 100,
		'choices'     => array(
			'min'  => 1,
			'max'  => 2,
			'step' => 1
		), ) )
	);


	/* Section - Blog - Blog Index Post Options */
   $wp_customize->add_section( 'secondline_themes_section_blog_options', array(
   	'title'          => esc_html__( 'Blog Post Options', 'podcaster-secondline' ),
   	'panel'          => 'secondline_themes_blog_panel', // Not typically needed.
   	'priority'       => 20,
   )
	);


	/* Setting - General - Page Title */
	$wp_customize->add_setting( 'secondline_themes_post_page_title_bg_image' ,array(
		'default' => get_template_directory_uri().'/images/page-title.jpg',
		'sanitize_callback' => 'esc_url_raw',
	) );
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'secondline_themes_post_page_title_bg_image', array(
		'label'    => esc_html__( 'Post Title Background Image', 'podcaster-secondline' ),
		'section' => 'secondline_themes_section_blog_options',
		'priority'   => 170,
		))
	);


	/* Setting - General - Page Title */
	$wp_customize->add_setting( 'secondline_themes_page_post_title_image_position' ,array(
		'default' => 'cover',
		'sanitize_callback' => 'secondline_themes_sanitize_choices',
	) );
	$wp_customize->add_control(new secondline_themes_Controls_Radio_Buttonset_Control($wp_customize, 'secondline_themes_page_post_title_image_position', array(
		'section' => 'secondline_themes_section_blog_options',
		'priority'   => 180,
		'choices'     => array(
			'cover' => esc_html__( 'Image Cover', 'podcaster-secondline' ),
			'repeat-all' => esc_html__( 'Image Pattern', 'podcaster-secondline' ),
		),
		))
	);



	/* Setting - Body - Page Title */
	$wp_customize->add_setting( 'secondline_themes_post_title_bg_color', array(
		'default' => '#000000',
		'sanitize_callback' => 'sanitize_hex_color',
	) );
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'secondline_themes_post_title_bg_color', array(
		'label'    => esc_html__( 'Page Title Background Color', 'podcaster-secondline' ),
		'section'  => 'secondline_themes_section_blog_options',
		'priority'   => 190,
		))
	);





   /* Section - Blog - Blog Post Options */
	$wp_customize->add_setting( 'secondline_themes_blog_post_sidebar' ,array(
		'default' => 'right',
		'sanitize_callback' => 'secondline_themes_sanitize_choices',
	) );
	$wp_customize->add_control(new secondline_themes_Controls_Radio_Buttonset_Control($wp_customize, 'secondline_themes_blog_post_sidebar', array(
		'label'    => esc_html__( 'Post Sidebar', 'podcaster-secondline' ),
		'section' => 'secondline_themes_section_blog_options',
		'priority'   => 330,
		'choices'     => array(
			'left' => esc_html__( 'Left', 'podcaster-secondline' ),
			'right' => esc_html__( 'Right', 'podcaster-secondline' ),
			'none' => esc_html__( 'No Sidebar', 'podcaster-secondline' ),
		),
		))
	);












	/* Setting - Body - Button Styles */
	$wp_customize->add_setting('secondline_themes_button_font_size',array(
		'default' => '18',
		'sanitize_callback' => 'secondline_themes_sanitize_choices',
	) );
	$wp_customize->add_control( new secondline_themes_Controls_Slider_Control($wp_customize, 'secondline_themes_button_font_size', array(
		'label'    => esc_html__( 'Button Font Size', 'podcaster-secondline' ),
		'section'  => 'secondline_themes_section_blog_options',
		'priority'   => 1600,
		'choices'     => array(
			'min'  => 0,
			'max'  => 30,
			'step' => 1
		), ) )
	);




	/* Panel - Footer */
	$wp_customize->add_panel( 'secondline_themes_footer_panel', array(
		'priority'    => 11,
        'title'       => esc_html__( 'Footer', 'podcaster-secondline' ),
    )
 	);




 	/* Setting - Footer - Footer Widgets */
	$wp_customize->add_setting('secondline_themes_widgets_margin_top',array(
		'default' => '65',
		'sanitize_callback' => 'secondline_themes_sanitize_choices',
	) );
	$wp_customize->add_control( new secondline_themes_Controls_Slider_Control($wp_customize, 'secondline_themes_widgets_margin_top', array(
		'label'    => esc_html__( 'Footer Widget Margin Top', 'podcaster-secondline' ),
 		'section' => 'secondline_themes_section_widget_layout',
		'priority'   => 20,
		'choices'     => array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1
		), ) )
	);


 	/* Setting - Footer - Footer Widgets */
	$wp_customize->add_setting('secondline_themes_widgets_margin_bottom',array(
		'default' => '40',
		'sanitize_callback' => 'secondline_themes_sanitize_choices',
	) );
	$wp_customize->add_control( new secondline_themes_Controls_Slider_Control($wp_customize, 'secondline_themes_widgets_margin_bottom', array(
		'label'    => esc_html__( 'Footer Widget Margin Bottom', 'podcaster-secondline' ),
 		'section' => 'secondline_themes_section_widget_layout',
		'priority'   => 22,
		'choices'     => array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1
		), ) )
	);





}
add_action( 'customize_register', 'secondline_themes_customizer' );

//HTML Text
function secondline_themes_sanitize_customizer( $input ) {
    return wp_kses_post( force_balance_tags( $input ) );
}

//no-HTML text
function secondline_themes_sanitize_choices( $input ) {
	return wp_filter_nohtml_kses( $input );
}

function secondline_themes_customizer_styles() {
	global $post;

	//https://codex.wordpress.org/Function_Reference/wp_add_inline_style
	wp_enqueue_style( 'secondline-themes-custom-style', get_template_directory_uri() . '/css/secondline_themes_custom_styles.css' );

   if ( get_theme_mod( 'secondline_themes_header_bg_image')  ) {
      $secondline_themes_header_bg_image = "background-image:url(" . esc_attr( get_theme_mod( 'secondline_themes_header_bg_image' ) ) . ");";
	}	else {
		$secondline_themes_header_bg_image = "";
	}

   if ( get_theme_mod( 'secondline_themes_header_drop_shadow') == 'on' ) {
      $secondline_themes_header_shadow_option = ".secondline-fixed-scrolled header#masthead-slt { box-shadow: 0px 2px 6px rgba(0,0,0, 0.06); }";
	}	else {
		$secondline_themes_header_shadow_option = "";
	}

   if ( get_theme_mod( 'secondline_themes_header_bg_image_image_position', 'cover') == 'cover' ) {
      $secondline_themes_header_bg_cover = "background-repeat: no-repeat; background-position:center center; background-size: cover;";
	}	else {
		$secondline_themes_header_bg_cover = "background-repeat:repeat-all; ";
	}

   if ( get_theme_mod( 'secondline_themes_body_bg_image') ) {
      $secondline_themes_body_bg = "background-image:url(" .   esc_attr( get_theme_mod( 'secondline_themes_body_bg_image') ). ");";
	}	else {
		$secondline_themes_body_bg = "";
	}

   if ( get_theme_mod( 'secondline_themes_body_bg_image_image_position', 'cover') == 'cover') {
      $secondline_themes_body_bg_cover = "background-repeat: no-repeat; background-position:center center; background-size: cover; background-attachment: fixed;";
	}	else {
		$secondline_themes_body_bg_cover = "background-repeat:repeat-all;";
	}

   if ( get_theme_mod( 'secondline_themes_page_title_image_position', 'cover') == 'cover' ) {
      $secondline_themes_page_tite_bg_cover = "background-repeat: no-repeat; background-position:center center; background-size: cover;";
	}	else {
		$secondline_themes_page_tite_bg_cover = "background-repeat:repeat-all;";
	}


   if ( get_theme_mod( 'secondline_themes_page_post_title_image_position', 'cover') == 'cover' ) {
      $secondline_themes_post_tite_bg_cover = "background-repeat: no-repeat; background-position:center center; background-size: cover;";
	}	else {
		$secondline_themes_post_tite_bg_cover = "background-repeat:repeat-all;";
	}

   if ( get_theme_mod( 'secondline_themes_page_title_overlay_color') ) {
      $secondline_themes_page_tite_overlay_image_cover = "#page-title-slt:before {background:" .  esc_attr( get_theme_mod('secondline_themes_page_title_overlay_color') ) . "; }";
	}	else {
		$secondline_themes_page_tite_overlay_image_cover = "";
	}

   if ( get_theme_mod( 'secondline_themes_post_title_overlay_color') ) {
      $secondline_themes_post_tite_overlay_image_cover = "#page-title-slt-post-page .secondline-themes-gallery .blog-single-gallery-post-format:before, #page-title-slt-post-page:before {background:" .  esc_attr( get_theme_mod('secondline_themes_post_title_overlay_color') ) . "; }";
	}	else {
		$secondline_themes_post_tite_overlay_image_cover = "";
	}

   if ( get_theme_mod( 'secondline_themes_fixed_logo_width', '0') != '0' ) {
      $secondline_themes_fixed_logo_width = "width:" .  esc_attr( get_theme_mod('secondline_themes_fixed_logo_width', '70') ) . "px;";
	}	else {
		$secondline_themes_fixed_logo_width = "";
	}

   if ( get_theme_mod( 'secondline_themes_fixed_logo_margin_top', '0') != '0' ) {
      $secondline_themes_fixed_logo_top = "padding-top:" .  esc_attr( get_theme_mod('secondline_themes_fixed_logo_margin_top', '31') ) . "px;";
	}	else {
		$secondline_themes_fixed_logo_top = "";
	}

   if ( get_theme_mod( 'secondline_themes_fixed_logo_margin_bottom', '0') != '0' ) {
      $secondline_themes_fixed_logo_bottom = "padding-bottom:" .  esc_attr( get_theme_mod('secondline_themes_fixed_logo_margin_bottom', '31') ) . "px;";
	}	else {
		$secondline_themes_fixed_logo_bottom = "";
	}

   if ( get_theme_mod( 'secondline_themes_fixed_nav_padding', '0') != '0' ) {
      $secondline_themes_fixed_nav_padding = "
		.secondline-fixed-scrolled .secondline-mini-banner-icon {
			top:" . esc_attr( (get_theme_mod('secondline_themes_fixed_nav_padding') - get_theme_mod('secondline_themes_nav_font_size', '15')) - 4 ). "px;
		}
		.secondline-fixed-scrolled #secondline-inline-icons .secondline-themes-social-icons a {
			padding-top:" . esc_attr( get_theme_mod('secondline_themes_fixed_nav_padding') - 3 ). "px;
			padding-bottom:" . esc_attr( get_theme_mod('secondline_themes_fixed_nav_padding') - 3 ). "px;
		}
		nav#secondline-themes-right-navigation ul {
			padding-top:" . esc_attr( get_theme_mod('secondline_themes_fixed_nav_padding') - 20 ). "px;
		}
		.secondline-fixed-scrolled #secondline-shopping-cart-count span.secondline-cart-count { top:" . esc_attr( get_theme_mod('secondline_themes_fixed_nav_padding') ). "px; }
		.secondline-fixed-scrolled #secondline-themes-header-search-icon i.pe-7s-search {
			padding-top:" . esc_attr( get_theme_mod('secondline_themes_fixed_nav_padding') - 5  ). "px;
			padding-bottom:" . esc_attr( get_theme_mod('secondline_themes_fixed_nav_padding') - 5 ). "px;
		}
		secondline-fixed-scrolled #secondline-shopping-cart-count a.secondline-count-icon-nav i.shopping-cart-header-icon {
					padding-top:" . esc_attr( get_theme_mod('secondline_themes_fixed_nav_padding') - 6  ). "px;
					padding-bottom:" . esc_attr( get_theme_mod('secondline_themes_fixed_nav_padding') - 6 ). "px;
		}
		.secondline-fixed-scrolled .sf-menu a {
			padding-top:" . esc_attr( get_theme_mod('secondline_themes_fixed_nav_padding') ). "px;
			padding-bottom:" . esc_attr( get_theme_mod('secondline_themes_fixed_nav_padding') ). "px;
		}
			";
	}	else {
		$secondline_themes_fixed_nav_padding = "";
	}


   if (  get_theme_mod( 'secondline_themes_fixed_nav_font_color') ) {
      $secondline_themes_fixed_nav_option_font_color = "
			.secondline-fixed-scrolled .active-mobile-icon-slt .mobile-menu-icon-slt, .secondline-fixed-scrolled .mobile-menu-icon-slt,  .secondline-fixed-scrolled .mobile-menu-icon-slt:hover,
	.secondline-fixed-scrolled #secondline-themes-header-search-icon i.pe-7s-search,
	.secondline-fixed-scrolled #secondline-inline-icons .secondline-themes-social-icons a, .secondline-fixed-scrolled .sf-menu a {
		color:" . esc_attr( get_theme_mod('secondline_themes_fixed_nav_font_color') ) . ";
	}";
	}	else {
		$secondline_themes_fixed_nav_option_font_color = "";
	}

   if ( get_theme_mod( 'secondline_themes_fixed_nav_font_color_hover') ) {
      $secondline_themes_optional_fixed_nav_font_hover = "
		.secondline-fixed-scrolled #secondline-themes-header-search-icon:hover i.pe-7s-search, .secondline-fixed-scrolled #secondline-themes-header-search-icon.active-search-icon-slt i.pe-7s-search, .secondline-fixed-scrolled #secondline-inline-icons .secondline-themes-social-icons a:hover, .secondline-fixed-scrolled .sf-menu a:hover, .secondline-fixed-scrolled .sf-menu li.sfHover a, .secondline-fixed-scrolled .sf-menu li.current-menu-item a {
		color:" . esc_attr( get_theme_mod('secondline_themes_fixed_nav_font_color_hover') ) . ";
	}";
	}	else {
		$secondline_themes_optional_fixed_nav_font_hover = "";
	}

   if ( get_theme_mod( 'secondline_themes_nav_bg') ) {
      $secondline_themes_optional_nav_bg = "background:" . esc_attr( get_theme_mod('secondline_themes_nav_bg') ). ";";
	}	else {
		$secondline_themes_optional_nav_bg = "";
	}


   if ( get_theme_mod( 'secondline_themes_slt_scroll_top', 'scroll-off-slt') == "scroll-off-slt" ) {
      $secondline_themes_scroll_top_disable = "display:none;";
	}	else {
		$secondline_themes_scroll_top_disable = "";
	}

   if ( get_theme_mod( 'secondline_themes_copyright_bg', '#e8e8e8')) {
      $secondline_themes_copyright_optional_bg = "background:".  esc_attr( get_theme_mod('secondline_themes_copyright_bg', '#e8e8e8') ). "; ";
	}	else {
		$secondline_themes_copyright_optional_bg = "";
	}

   if ( get_theme_mod( 'secondline_themes_nav_bg_hover') ) {
      $secondline_themes_optiona_nav_bg_hover = ".sf-menu a:hover, .sf-menu li.sfHover a, .sf-menu li.current-menu-item a { background:".  esc_attr( get_theme_mod('secondline_themes_nav_bg_hover') ). "; }";
	}	else {
		$secondline_themes_optiona_nav_bg_hover = "";
	}

   if ( get_theme_mod( 'secondline_themes_fixed_nav_font_bg') ) {
      $secondline_themes_optiona_fixed_nav_font_bg = ".secondline-fixed-scrolled .sf-menu a { background:".  esc_attr( get_theme_mod('secondline_themes_fixed_nav_font_bg') ). "; }";
	}	else {
		$secondline_themes_optiona_fixed_nav_font_bg = "";
	}

   if ( get_theme_mod( 'secondline_themes_fixed_nav_font_hover_bg') ) {
      $secondline_themes_optiona_fixed_nav_hover_bg = ".secondline-fixed-scrolled .sf-menu a:hover, .secondline-fixed-scrolled .sf-menu li.sfHover a, .secondline-fixed-scrolled .sf-menu li.current-menu-item a { background:".  esc_attr( get_theme_mod('secondline_themes_fixed_nav_font_hover_bg') ). "; }";
	}	else {
		$secondline_themes_optiona_fixed_nav_hover_bg = "";
	}

   if ( get_theme_mod( 'secondline_themes_fixed_nav_font_color') ) {
      $secondline_themes_option_fixed_nav_font_color = ".secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled #secondline-inline-icons .secondline-themes-social-icons a, .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled #secondline-themes-header-search-icon i.pe-7s-search, .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu a, .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled #secondline-inline-icons .secondline-themes-social-icons a, .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled #secondline-themes-header-search-icon i.pe-7s-search, .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu a {
		color:". esc_attr( get_theme_mod('secondline_themes_fixed_nav_font_color') ). ";
	}";
	}	else {
		$secondline_themes_option_fixed_nav_font_color = "";
	}

   if ( get_theme_mod( 'secondline_themes_fixed_nav_font_color_hover') ) {
      $secondline_themes_option_stickY_nav_font_hover_color = ".secondline_themes_force_light_navigation_color .secondline-fixed-scrolled #secondline-themes-header-search-icon:hover i.pe-7s-search, .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled #secondline-themes-header-search-icon.active-search-icon-slt i.pe-7s-search, .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled #secondline-inline-icons .secondline-themes-social-icons a:hover,  .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu a:hover, .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover a, .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.current-menu-item a,
	.secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled #secondline-themes-header-search-icon:hover i.pe-7s-search, .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled #secondline-themes-header-search-icon.active-search-icon-slt i.pe-7s-search, .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled #secondline-inline-icons .secondline-themes-social-icons a:hover,  .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu a:hover, .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover a, .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu li.current-menu-item a {
		color:" . esc_attr( get_theme_mod('secondline_themes_fixed_nav_font_color_hover') ) . ";
	}";
	}	else {
		$secondline_themes_option_stickY_nav_font_hover_color = "";
	}




   if ( get_theme_mod( 'secondline_themes_fixed_nav_highlight_font') ) {
      $secondline_themes_option_fixed_hightlight_font_color = "body .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.highlight-button a:before, body .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu li.highlight-button a:before, .secondline-fixed-scrolled .sf-menu li.sfHover.highlight-button a, .secondline-fixed-scrolled .sf-menu li.current-menu-item.highlight-button a, .secondline-fixed-scrolled .sf-menu li.highlight-button a, .secondline-fixed-scrolled .sf-menu li.highlight-button a:hover { color:".  esc_attr( get_theme_mod('secondline_themes_fixed_nav_highlight_font') ). "; }";
	}	else {
		$secondline_themes_option_fixed_hightlight_font_color = "";
	}

   if ( get_theme_mod( 'secondline_themes_fixed_nav_highlight_button') ) {
      $secondline_themes_option_fixed_hightlight_bg_color = "body .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.highlight-button a:hover, body .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu li.highlight-button a:hover, body .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.highlight-button a:before, body  .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu li.highlight-button a:before, .secondline-fixed-scrolled .sf-menu li.current-menu-item.highlight-button a:before, .secondline-fixed-scrolled .sf-menu li.highlight-button a:before { background:".  esc_attr( get_theme_mod('secondline_themes_fixed_nav_highlight_button') ). "; }";
	}	else {
		$secondline_themes_option_fixed_hightlight_bg_color = "";
	}

   if ( get_theme_mod( 'secondline_themes_fixed_nav_highlight_button_hover') ) {
      $secondline_themes_option_fixed_hightlight_bg_color_hover = "body .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.highlight-button a:hover:before,  body .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu li.highlight-button a:hover:before,
	body .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.current-menu-item.highlight-button a:hover:before, body .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.highlight-button a:hover:before, .secondline-fixed-scrolled .sf-menu li.current-menu-item.highlight-button a:hover:before, .secondline-fixed-scrolled .sf-menu li.highlight-button a:hover:before { background:".  esc_attr( get_theme_mod('secondline_themes_fixed_nav_highlight_button_hover') ). "; }";
	}	else {
		$secondline_themes_option_fixed_hightlight_bg_color_hover = "";
	}

   if ( get_theme_mod( 'secondline_themes_mobile_header_bg') ) {
      $secondline_themes_mobile_header_bg_color = ".secondline-themes-transparent-header header#masthead-slt, header#masthead-slt {background:". esc_attr( get_theme_mod('secondline_themes_mobile_header_bg') ) . ";  }";
	}	else {
		$secondline_themes_mobile_header_bg_color = "";
	}

   if ( get_theme_mod( 'secondline_themes_mobile_header_logo_width') ) {
      $secondline_themes_mobile_header_logo_width = "body #logo-slt img { width:" . esc_attr( get_theme_mod('secondline_themes_mobile_header_logo_width') ). "px; } ";
	}	else {
		$secondline_themes_mobile_header_logo_width = "";
	}

   if ( get_theme_mod( 'secondline_themes_mobile_header_logo_margin') ) {
      $secondline_themes_mobile_header_logo_margin_top = " body #logo-slt img { padding-top:". esc_attr( get_theme_mod('secondline_themes_mobile_header_logo_margin') ). "px; padding-bottom:". esc_attr( get_theme_mod('secondline_themes_mobile_header_logo_margin') ). "px; }";
	}	else {
		$secondline_themes_mobile_header_logo_margin_top = "";
	}

   if ( get_theme_mod( 'secondline_themes_header_border_bottom_color', 'rgba(255,255,255, 0.15)') ) {
      $secondline_themes_main_header_border = "
		 header#masthead-slt:after { display:block; background:" . esc_attr( get_theme_mod('secondline_themes_header_border_bottom_color' , 'rgba(255,255,255, 0.15)' ) ) . ";
	}";
	}	else {
		$secondline_themes_main_header_border = "";
	}

   if ( get_theme_mod( 'secondline_themes_fixed_nav_border_color', 'rgba(0,0,0,0.15)') ) {
      $secondline_themes_fixed_nav_border = "
		 .secondline-fixed-scrolled  header#masthead-slt:after { display:block; background:" . esc_attr( get_theme_mod('secondline_themes_fixed_nav_border_color', 'rgba(0,0,0,0.15)') ) . ";
	}";
	}	else {
		$secondline_themes_fixed_nav_border = ".secondline-fixed-scrolled header#masthead-slt:after { opacity:0; }";
	}

   if ( get_theme_mod( 'secondline_themes_mobile_header_nav_padding') ) {
      $secondline_themes_mobile_header_nav_padding_top = "		#secondline-shopping-cart-count span.secondline-cart-count {top:" . esc_attr( get_theme_mod('secondline_themes_mobile_header_nav_padding')  ) . "px;}
		.mobile-menu-icon-slt {padding-top:" . esc_attr( get_theme_mod('secondline_themes_mobile_header_nav_padding') - 3 ) . "px; padding-bottom:" . esc_attr( get_theme_mod('secondline_themes_mobile_header_nav_padding') - 5 ) . "px; }
		#secondline-shopping-cart-count a.secondline-count-icon-nav i.shopping-cart-header-icon {
			padding-top:" . esc_attr( get_theme_mod('secondline_themes_mobile_header_nav_padding') - 6 ) . "px;
			padding-bottom:" . esc_attr( get_theme_mod('secondline_themes_mobile_header_nav_padding') - 6 ) . "px;
		}";
	}	else {
		$secondline_themes_mobile_header_nav_padding_top = "";
	}



   if ( get_theme_mod( 'secondline_themes_footer_main_bg_image') ) {
      $secondline_themes_footer_bg_image = "background-image:url(" . esc_attr( get_theme_mod( 'secondline_themes_footer_main_bg_image') ) . ");";
	}	else {
		$secondline_themes_footer_bg_image = "";
	}

   if ( get_theme_mod( 'secondline_themes_main_image_position', 'cover') == 'cover' ) {
      $secondline_themes_main_image_position_cover = "background-repeat: no-repeat; background-position:center center; background-size: cover;";
	}	else {
		$secondline_themes_main_image_position_cover = "background-repeat:repeat-all;";
	}


   if (  function_exists('z_taxonomy_image_url') && z_taxonomy_image_url() ) {
      $secondline_themes_custom_tax_page_title_img = "body #page-title-slt {background-image:url('" . esc_url( z_taxonomy_image_url() ) . "'); }";
	}	else {
		$secondline_themes_custom_tax_page_title_img = "";
	}

   if ( is_page() && get_post_meta($post->ID, 'secondline_themes_header_image', true ) ) {
      $secondline_themes_custom_page_title_img = "body #page-title-slt {background-image:url('" . esc_url( get_post_meta($post->ID, 'secondline_themes_header_image', true)) . "'); }";
	}	else {
		$secondline_themes_custom_page_title_img = "";
	}

   if ( is_singular('post') && get_post_meta($post->ID, 'secondline_themes_header_image', true ) ) {
      $secondline_themes_custom_post_slt_title_img = "body #page-title-slt-post-page {background-image:url('" . esc_url( get_post_meta($post->ID, 'secondline_themes_header_image', true)) . "'); }";
	}	else {
		$secondline_themes_custom_post_slt_title_img = "";
	}

   if ( get_option( 'page_for_posts' ) ) {
		$cover_page = get_page( get_option( 'page_for_posts' ));
		 if ( is_home() && get_post_meta($cover_page->ID, 'secondline_themes_header_image', true) || is_singular( 'post') && get_post_meta($cover_page->ID, 'secondline_themes_header_image', true)|| is_category( ) && get_post_meta($cover_page->ID, 'secondline_themes_header_image', true) ) {
			$secondline_themes_blog_header_img = "body #page-title-slt {background-image:url('" .  esc_url( get_post_meta($cover_page->ID, 'secondline_themes_header_image', true) ). "'); }";
		} else {
		$secondline_themes_blog_header_img = ""; }
	}	else {
		$secondline_themes_blog_header_img = "";
	}

   if ( get_theme_mod( 'secondline_themes_page_title_underline_color') ) {
      $secondline_themes_page_title_optional_underline = "#page-title-slt h1:after {background:" . esc_attr( get_theme_mod('secondline_themes_page_title_underline_color') )  . "; display:block;}";
	}	else {
		$secondline_themes_page_title_optional_underline = "";
	}

   if ( get_theme_mod( 'secondline_themes_top_header_background', '#4c4b46') ) {
      $secondline_themes_top_header_background_option = "background:" . esc_attr( get_theme_mod('secondline_themes_top_header_background', '#4c4b46') )  . ";";
	}	else {
		$secondline_themes_top_header_background_option = "";
	}

   if ( get_theme_mod( 'secondline_themes_top_header_border_bottom') ) {
      $secondline_themes_top_header_border_bottom_option = "border-bottom:1px solid " . esc_attr( get_theme_mod('secondline_themes_top_header_border_bottom') )  . ";";
	}	else {
		$secondline_themes_top_header_border_bottom_option = "";
	}


   if ( get_theme_mod( 'secondline_themes_blog_content_background', '#ffffff') ) {
      $secondline_themes_blog_background_content = ".secondline-blog-content { background:".  esc_attr( get_theme_mod('secondline_themes_blog_content_background', '#ffffff') ). "; }";
	}	else {
		$secondline_themes_blog_background_content = "";
	}

   if ( get_theme_mod( 'secondline_themes_blog_conent_border') ) {
      $secondline_themes_blog_background_content_border = ".secondline-blog-content { border:1px solid ".  esc_attr( get_theme_mod('secondline_themes_blog_conent_border') ). ";  }";
	}	else {
		$secondline_themes_blog_background_content_border = "";
	}


    $secondline_themes_boxed_layout = "";

	$secondline_themes_custom_css = "
	$secondline_themes_custom_page_title_img
	$secondline_themes_custom_tax_page_title_img
	$secondline_themes_blog_header_img
    $secondline_themes_custom_post_slt_title_img
	body #logo-slt img {
		width:" .  esc_attr( get_theme_mod('secondline_themes_theme_logo_width', '203') ) . "px;
		padding-top:" .  esc_attr( get_theme_mod('secondline_themes_theme_logo_margin_top', '19') ) . "px;
		padding-bottom:" .  esc_attr( get_theme_mod('secondline_themes_theme_logo_margin_bottom', '29') ) . "px;
	}
	#boxed-layout-slt #content-slt p.stars a, #boxed-layout-slt #content-slt p.stars a:hover, #boxed-layout-slt #content-slt .star-rating, a, .secondline-post-meta i {
		color:" .  esc_attr( get_theme_mod('secondline_themes_default_link_color', '#2d2d2d') ) . ";
	}
	a:hover {
		color:" .  esc_attr( get_theme_mod('secondline_themes_default_link_hover_color', '#ff4102') ). ";
	}
	header .sf-mega {margin-left:-" .  esc_attr( get_theme_mod('secondline_themes_site_width', '1400') / 2 ) . "px; width:" .  esc_attr( get_theme_mod('secondline_themes_site_width', '1400') ) . "px;}
	body .elementor-section.elementor-section-boxed > .elementor-container {max-width:" .  esc_attr( get_theme_mod('secondline_themes_site_width', '1400') ) . "px;}
	.width-container-slt {  width:" .  esc_attr( get_theme_mod('secondline_themes_site_width', '1400') ) . "px; }
	body.secondline-themes-header-sidebar-before #secondline-inline-icons .secondline-themes-social-icons, body.secondline-themes-header-sidebar-before:before, header#masthead-slt {		
		$secondline_themes_header_bg_image
		$secondline_themes_header_bg_cover
	}
	$secondline_themes_header_shadow_option
	$secondline_themes_main_header_border
	$secondline_themes_fixed_nav_border
	body {
		background-color:" .   esc_attr( get_theme_mod('secondline_themes_background_color', '#ffffff') ). ";
		$secondline_themes_body_bg
		$secondline_themes_body_bg_cover
	}
	#page-title-slt {
		background-color:" .   esc_attr( get_theme_mod('secondline_themes_page_title_bg_color', '#000000') ). ";
		background-image:url(" .   esc_attr( get_theme_mod( 'secondline_themes_page_title_bg_image',  get_template_directory_uri().'/images/page-title.jpg' ) ). ");
		padding-top:" . esc_attr( get_theme_mod('secondline_themes_page_title_padding_top', '184') ). "px;
		padding-bottom:" .  esc_attr( get_theme_mod('secondline_themes_page_title_padding_bottom', '130') ). "px;
		$secondline_themes_page_tite_bg_cover
	}
	$secondline_themes_page_tite_overlay_image_cover
	$secondline_themes_page_title_optional_underline
	.sidebar-item { background:" .   esc_attr( get_theme_mod('secondline_themes_sidebar_background') ). "; }
	.sidebar ul ul, .sidebar ul li, .widget .widget_shopping_cart_content p.buttons { border-color:" .   esc_attr( get_theme_mod('secondline_themes_sidebar_divider', '#c2c3c5') ). "; }

	/* START BLOG STYLES */
	#page-title-slt-post-page {
		background-color: " . esc_attr( get_theme_mod('secondline_themes_post_title_bg_color', '#000000') ) . ";
		background-image:url(" .   esc_attr( get_theme_mod( 'secondline_themes_post_page_title_bg_image',  get_template_directory_uri().'/images/page-title.jpg' ) ). ");
		$secondline_themes_post_tite_bg_cover
	}
	$secondline_themes_post_tite_overlay_image_cover

	.secondline-themes-feaured-image {background:" . esc_attr( get_theme_mod('secondline_themes_blog_image_bg') ) . ";}
	.secondline-themes-default-blog-overlay:hover a img, .secondline-themes-feaured-image:hover a img { opacity:" . esc_attr( get_theme_mod('secondline_themes_blog_image_opacity', '1') ) . ";}
	h2.secondline-blog-title a {color:" . esc_attr( get_theme_mod('secondline_themes_blog_title_link', '#070707') ) . ";}
	h2.secondline-blog-title a:hover {color:" . esc_attr( get_theme_mod('secondline_themes_blog_title_link_hover', '#2d2d2d') ) . ";}
	body h2.overlay-secondline-blog-title, body .overlay-blog-meta-category-list span, body .secondline-themes-default-blog-overlay .secondline-post-meta, body  .overlay-blog-floating-comments-viewcount {color:" . esc_attr( get_theme_mod('secondline_themes_overlay_blog_title_link', '#ffffff') ) . ";}
	$secondline_themes_blog_background_content
	$secondline_themes_blog_background_content_border
	#page-title-slt-post-page, #page-title-slt-post-page .secondline-themes-gallery .blog-single-gallery-post-format { height:" . esc_attr( get_theme_mod('secondline_themes_blog_post_height', '600') ) . "px; }
	#blog-post-title-meta-container { padding-bottom:" . esc_attr( get_theme_mod('secondline_themes_blog_post_meta_padding', '105') ) . "px; }
	/* END BLOG STYLES */

	/* START BUTTON STYLES */
	#boxed-layout-slt .form-submit input#submit, #boxed-layout-slt input.button, .tml-submit-wrap input.button-primary, .acf-form-submit input.button, .tml input#wp-submit, #boxed-layout-slt #customer_login input.button, #boxed-layout-slt button.button, #boxed-layout-slt a.button, .infinite-nav-slt a, #newsletter-form-fields input.button, a.secondline-themes-button, .secondline-themes-sticky-post, .post-password-form input[type=submit], #respond input#submit, .wpcf7-form input.wpcf7-submit {
		font-size:" . esc_attr( get_theme_mod('secondline_themes_button_font_size', '18') ) . "px;
		background:" . esc_attr( get_theme_mod('secondline_themes_button_background', '#2d2d2d') ) . ";
		color:" . esc_attr( get_theme_mod('secondline_themes_button_font', '#ffffff') ) . ";
	}
	#boxed-layout-slt button.button, #boxed-layout-slt a.button { font-size:" . esc_attr( get_theme_mod('secondline_themes_button_font_size', '18') - 1 ) . "px; }
	#boxed-layout-slt .form-submit input#submit:hover, #boxed-layout-slt input.button:hover, .tml-submit-wrap input.button-primary:hover, .acf-form-submit input.button:hover, .tml input#wp-submit:hover, #boxed-layout-slt #customer_login input.button:hover, #boxed-layout-slt button.button:hover, #boxed-layout-slt a.button:hover, .infinite-nav-slt a:hover, #newsletter-form-fields input.button:hover, a.secondline-themes-button:hover, .post-password-form input[type=submit]:hover, #respond input#submit:hover, .wpcf7-form input.wpcf7-submit:hover {
		background:" . esc_attr( get_theme_mod('secondline_themes_button_background_hover', '#4c4b46') ) . ";
		color:" . esc_attr( get_theme_mod('secondline_themes_button_font_hover', '#ffffff') ) . ";
	}
	form#mc-embedded-subscribe-form  .mc-field-group input:focus, body .acf-form .acf-field .acf-input textarea:focus, body .acf-form .acf-field .acf-input-wrap input:focus, .tml input:focus, .tml textarea:focus, .widget select:focus, #newsletter-form-fields input:focus, .wpcf7-form select:focus, blockquote, .post-password-form input:focus, .search-form input.search-field:focus, #respond textarea:focus, #respond input:focus, .wpcf7-form input:focus, .wpcf7-form textarea:focus { border-color:" . esc_attr( get_theme_mod('secondline_themes_button_background', '#2d2d2d') ) . ";  }
	/* END BUTTON STYLES */

	/* START Fixed Nav Styles */
	.secondline-themes-transparent-header .secondline-fixed-scrolled header#masthead-slt, .secondline-fixed-scrolled header#masthead-slt, #secondline-fixed-nav.secondline-fixed-scrolled { background-color:" .   esc_attr( get_theme_mod('secondline_themes_fixed_nav_background_color', 'rgba(255,255,255, 0.7)') ) ."; }
	body .secondline-fixed-scrolled #logo-po img {
		$secondline_themes_fixed_logo_width
		$secondline_themes_fixed_logo_top
		$secondline_themes_fixed_logo_bottom
	}
	$secondline_themes_fixed_nav_padding
	$secondline_themes_fixed_nav_option_font_color
	$secondline_themes_optional_fixed_nav_font_hover
	/* END Fixed Nav Styles */
	/* START Main Navigation Customizer Styles */
	#secondline-shopping-cart-count a.secondline-count-icon-nav, nav#site-navigation { letter-spacing: ". esc_attr( get_theme_mod('secondline_themes_nav_letterspacing', '0.5') ). "px; }
	#secondline-inline-icons .secondline-themes-social-icons a {
		color:" . esc_attr( get_theme_mod('secondline_themes_nav_font_color', '#eeeeee') ). ";
		padding-top:" . esc_attr( get_theme_mod('secondline_themes_nav_padding', '35') +1 ). "px;
		padding-bottom:" . esc_attr( get_theme_mod('secondline_themes_nav_padding', '35') +1 ). "px;
		font-size:" . esc_attr( get_theme_mod('secondline_themes_nav_font_size', '15')  ). "px;
	}
	.mobile-menu-icon-slt {
		min-width:" . esc_attr( get_theme_mod('secondline_themes_nav_font_size', '15') + 6 ). "px;
		color:" . esc_attr( get_theme_mod('secondline_themes_nav_font_color', '#000000') ). ";
		padding-top:" . esc_attr( get_theme_mod('secondline_themes_nav_padding', '35') - 3 ). "px;
		padding-bottom:" . esc_attr( get_theme_mod('secondline_themes_nav_padding', '35') - 5 ). "px;
		font-size:" . esc_attr( get_theme_mod('secondline_themes_nav_font_size', '15') + 6 ). "px;
	}
	.mobile-menu-icon-slt span.secondline-mobile-menu-text {
		font-size:" . esc_attr( get_theme_mod('secondline_themes_nav_font_size', '15') ). "px;
	}
	#secondline-shopping-cart-count span.secondline-cart-count {
		top:" . esc_attr( get_theme_mod('secondline_themes_nav_padding', '35') - 1). "px;
	}
	#secondline-shopping-cart-count a.secondline-count-icon-nav i.shopping-cart-header-icon {
		color:" . esc_attr( get_theme_mod('secondline_themes_nav_cart_icon_main_color', '#ffffff') ). ";
		background:" . esc_attr( get_theme_mod('secondline_themes_nav_cart_icon_main_bg', '#213a70') ). ";
		padding-top:" . esc_attr( get_theme_mod('secondline_themes_nav_padding', '35') - 6 ). "px;
		padding-bottom:" . esc_attr( get_theme_mod('secondline_themes_nav_padding', '35') - 6 ). "px;
		font-size:" . esc_attr( get_theme_mod('secondline_themes_nav_font_size', '15') + 12 ). "px;
	}
	#secondline-shopping-cart-count a.secondline-count-icon-nav i.shopping-cart-header-icon:hover,
	.activated-class #secondline-shopping-cart-count a.secondline-count-icon-nav i.shopping-cart-header-icon {
		color:" . esc_attr( get_theme_mod('secondline_themes_nav_cart_icon_main_color', '#ffffff') ). ";
		background:" . esc_attr( get_theme_mod('secondline_themes_nav_cart_icon_main_bg_hover', '#254682') ). ";
	}
	#secondline-themes-header-search-icon i.pe-7s-search {
		color:" . esc_attr( get_theme_mod('secondline_themes_nav_font_color', '#eeeeee') ). ";
		padding-top:" . esc_attr( get_theme_mod('secondline_themes_nav_padding', '35') - 5 ). "px;
		padding-bottom:" . esc_attr( get_theme_mod('secondline_themes_nav_padding', '35') - 5 ). "px;
		font-size:" . esc_attr( get_theme_mod('secondline_themes_nav_font_size', '15') + 10 ). "px;
	}
	nav#secondline-themes-right-navigation ul {
		padding-top:" . esc_attr( get_theme_mod('secondline_themes_nav_padding', '35') - 20 ). "px;
	}
	nav#secondline-themes-right-navigation ul li a {
		font-size:" . esc_attr( get_theme_mod('secondline_themes_nav_font_size', '15') ). "px;
	}
	.sf-menu a {
		color:" . esc_attr( get_theme_mod('secondline_themes_nav_font_color', '#2d2d2d') ). ";
		padding-top:" . esc_attr( get_theme_mod('secondline_themes_nav_padding', '35') ). "px;
		padding-bottom:" . esc_attr( get_theme_mod('secondline_themes_nav_padding', '35') ). "px;
		font-size:" . esc_attr( get_theme_mod('secondline_themes_nav_font_size', '15') ). "px;
		$secondline_themes_optional_nav_bg
	}
	.secondline_themes_force_light_navigation_color .secondline-fixed-scrolled  #secondline-inline-icons .secondline-themes-social-icons a,
	.secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled  #secondline-inline-icons .secondline-themes-social-icons a,
	.secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled #secondline-themes-header-search-icon i.pe-7s-search,
	.secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu a,
	.secondline_themes_force_light_navigation_color .secondline-fixed-scrolled #secondline-themes-header-search-icon i.pe-7s-search,
	.secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu a  {
		color:" . esc_attr( get_theme_mod('secondline_themes_nav_font_color', '#eeeeee') ). ";
	}
	.secondline_themes_force_light_navigation_color .secondline-fixed-scrolled  #secondline-inline-icons .secondline-themes-social-icons a:hover,
	.secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled  #secondline-inline-icons .secondline-themes-social-icons a:hover,
	.active-mobile-icon-slt .mobile-menu-icon-slt,
	.mobile-menu-icon-slt:hover,
	.secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled #secondline-themes-header-search-icon:hover i.pe-7s-search,
	.secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled #secondline-themes-header-search-icon.active-search-icon-slt i.pe-7s-search,
	.secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled #secondline-inline-icons .secondline-themes-social-icons a:hover,
	.secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled #secondline-shopping-cart-count a.secondline-count-icon-nav:hover,
	.secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu a:hover,
	.secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover a,
	.secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu li.current-menu-item a,
	.secondline_themes_force_light_navigation_color .secondline-fixed-scrolled #secondline-themes-header-search-icon:hover i.pe-7s-search,
	.secondline_themes_force_light_navigation_color .secondline-fixed-scrolled #secondline-themes-header-search-icon.active-search-icon-slt i.pe-7s-search,
	.secondline_themes_force_light_navigation_color .secondline-fixed-scrolled #secondline-inline-icons .secondline-themes-social-icons a:hover,
	.secondline_themes_force_light_navigation_color .secondline-fixed-scrolled #secondline-shopping-cart-count a.secondline-count-icon-nav:hover,
	.secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu a:hover,
	.secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover a,
	.secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.current-menu-item a,
	#secondline-themes-header-search-icon:hover i.pe-7s-search, #secondline-themes-header-search-icon.active-search-icon-slt i.pe-7s-search, #secondline-inline-icons .secondline-themes-social-icons a:hover, #secondline-shopping-cart-count a.secondline-count-icon-nav:hover, .sf-menu a:hover, .sf-menu li.sfHover a, .sf-menu li.current-menu-item a {
		color:". esc_attr( get_theme_mod('secondline_themes_nav_font_color_hover', '#000000') ) . ";
	}
    .sf-menu a:hover:before, .sf-menu li.sfHover a:before, .sf-menu li.current-menu-item a:before {
        background:". esc_attr( get_theme_mod('secondline_themes_nav_font_color_hover', '#000000') ) . ";
        opacity: 1;
    }

	#secondline-checkout-basket, #panel-search-secondline, .sf-menu ul {
		background:".  esc_attr( get_theme_mod('secondline_themes_sub_nav_bg', '#2d2d2d') ). ";
	}
	#main-nav-mobile { background:".  esc_attr( get_theme_mod('secondline_themes_sub_nav_bg', '#2d2d2d') ). "; }
	#main-nav-mobile { border-top:2px solid ".  esc_attr( get_theme_mod('secondline_themes_sub_nav_border_top_color', '#ff4102') ). "; }
	ul.mobile-menu-slt li a { color:" . esc_attr( get_theme_mod('secondline_themes_sub_nav_font_color', '#c3c3c3') ) . "; }
	ul.mobile-menu-slt .sf-mega .sf-mega-section li a, ul.mobile-menu-slt .sf-mega .sf-mega-section, ul.mobile-menu-slt.collapsed li a {border-color:" . esc_attr( get_theme_mod('secondline_themes_sub_nav_border_color', '#444444') ) . ";}

	#panel-search-secondline, .sf-menu ul {border-color:".  esc_attr( get_theme_mod('secondline_themes_sub_nav_border_top_color', '#ff4102') ). ";}
	.sf-menu li li a {
		letter-spacing:".  esc_attr( get_theme_mod('secondline_themes_sub_nav_letterspacing', '0') ). "px;
		font-size:".  esc_attr( get_theme_mod('secondline_themes_sub_nav_font_size', '13') ). "px;
	}
	#secondline-checkout-basket .secondline-sub-total {
		font-size:".  esc_attr( get_theme_mod('secondline_themes_sub_nav_font_size', '13' ) ). "px;
	}
	#panel-search-secondline input, #secondline-checkout-basket ul#secondline-cart-small li.empty {
		font-size:".  esc_attr( get_theme_mod('secondline_themes_sub_nav_font_size', '13' ) ). "px;
	}
	.secondline-fixed-scrolled #secondline-checkout-basket, .secondline-fixed-scrolled #secondline-checkout-basket a, .secondline-fixed-scrolled .sf-menu li.sfHover li a, .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li a, .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover li a, .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li a, .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover li a, #panel-search-secondline .search-form input.search-field, .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li a, .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li a, .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover li a, .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li a, .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover li a, .secondline_themes_force_dark_navigation_color .sf-menu li.sfHover li a, .secondline_themes_force_dark_navigation_color .sf-menu li.sfHover li.sfHover li a, .secondline_themes_force_dark_navigation_color .sf-menu li.sfHover li.sfHover li.sfHover li a, .secondline_themes_force_dark_navigation_color .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li a, .secondline_themes_force_dark_navigation_color .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover li a, .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li a, .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li a, .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover li a, .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li a, .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover li a, .secondline_themes_force_light_navigation_color .sf-menu li.sfHover li a, .secondline_themes_force_light_navigation_color .sf-menu li.sfHover li.sfHover li a, .secondline_themes_force_light_navigation_color .sf-menu li.sfHover li.sfHover li.sfHover li a, .secondline_themes_force_light_navigation_color .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li a, .secondline_themes_force_light_navigation_color .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover li a, .sf-menu li.sfHover.highlight-button li a, .sf-menu li.current-menu-item.highlight-button li a, .secondline-fixed-scrolled #secondline-checkout-basket a.cart-button-header-cart:hover, .secondline-fixed-scrolled #secondline-checkout-basket a.checkout-button-header-cart:hover, #secondline-checkout-basket a.cart-button-header-cart:hover, #secondline-checkout-basket a.checkout-button-header-cart:hover, #secondline-checkout-basket, #secondline-checkout-basket a, .sf-menu li.sfHover li a, .sf-menu li.sfHover li.sfHover li a, .sf-menu li.sfHover li.sfHover li.sfHover li a, .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li a, .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover li a {
		color:" . esc_attr( get_theme_mod('secondline_themes_sub_nav_font_color', '#c3c3c3') ) . ";
	}
	.secondline-fixed-scrolled .sf-menu li li a:hover,  .secondline-fixed-scrolled .sf-menu li.sfHover li a, .secondline-fixed-scrolled .sf-menu li.current-menu-item li a, .sf-menu li.sfHover li a, .sf-menu li.sfHover li.sfHover li a, .sf-menu li.sfHover li.sfHover li.sfHover li a, .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li a, .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover li a {
		background:none;
	}
	.secondline-fixed-scrolled #secondline-checkout-basket a:hover, .secondline-fixed-scrolled #secondline-checkout-basket ul#secondline-cart-small li h6, .secondline-fixed-scrolled #secondline-checkout-basket .secondline-sub-total span.total-number-add, .secondline-fixed-scrolled .sf-menu li.sfHover li a:hover, .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover a, .secondline-fixed-scrolled .sf-menu li.sfHover li li a:hover, .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover a, .secondline-fixed-scrolled .sf-menu li.sfHover li li li a:hover, .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover a:hover, .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover a, .secondline-fixed-scrolled .sf-menu li.sfHover li li li li a:hover, .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover a:hover, .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover a, .secondline-fixed-scrolled .sf-menu li.sfHover li li li li li a:hover, .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover a:hover, .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover a, .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li a:hover, .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover a, .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li li a:hover, .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover a, .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li li li a:hover, .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover a:hover, .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover a, .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li li li li a:hover, .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover a:hover, .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover a, .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li li li li li a:hover, .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover a:hover, .secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover a, .secondline_themes_force_dark_navigation_color .sf-menu li.sfHover li a:hover, .secondline_themes_force_dark_navigation_color .sf-menu li.sfHover li.sfHover a, .secondline_themes_force_dark_navigation_color .sf-menu li.sfHover li li a:hover, .secondline_themes_force_dark_navigation_color .sf-menu li.sfHover li.sfHover li.sfHover a, .secondline_themes_force_dark_navigation_color .sf-menu li.sfHover li li li a:hover, .secondline_themes_force_dark_navigation_color .sf-menu li.sfHover li.sfHover li.sfHover a:hover, .secondline_themes_force_dark_navigation_color .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover a, .secondline_themes_force_dark_navigation_color .sf-menu li.sfHover li li li li a:hover, .secondline_themes_force_dark_navigation_color .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover a:hover, .secondline_themes_force_dark_navigation_color .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover a, .secondline_themes_force_dark_navigation_color .sf-menu li.sfHover li li li li li a:hover, .secondline_themes_force_dark_navigation_color .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover a:hover, .secondline_themes_force_dark_navigation_color .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover a, .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li a:hover, .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover a, .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li li a:hover, .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover a, .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li li li a:hover, .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover a:hover, .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover a, .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li li li li a:hover, .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover a:hover, .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover a, .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li li li li li a:hover, .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover a:hover, .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover a, .secondline_themes_force_light_navigation_color .sf-menu li.sfHover li a:hover, .secondline_themes_force_light_navigation_color .sf-menu li.sfHover li.sfHover a, .secondline_themes_force_light_navigation_color .sf-menu li.sfHover li li a:hover, .secondline_themes_force_light_navigation_color .sf-menu li.sfHover li.sfHover li.sfHover a, .secondline_themes_force_light_navigation_color .sf-menu li.sfHover li li li a:hover, .secondline_themes_force_light_navigation_color .sf-menu li.sfHover li.sfHover li.sfHover a:hover, .secondline_themes_force_light_navigation_color .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover a, .secondline_themes_force_light_navigation_color .sf-menu li.sfHover li li li li a:hover, .secondline_themes_force_light_navigation_color .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover a:hover, .secondline_themes_force_light_navigation_color .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover a, .secondline_themes_force_light_navigation_color .sf-menu li.sfHover li li li li li a:hover, .secondline_themes_force_light_navigation_color .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover a:hover, .secondline_themes_force_light_navigation_color .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover a, .sf-menu li.sfHover.highlight-button li a:hover, .sf-menu li.current-menu-item.highlight-button li a:hover, #secondline-checkout-basket a.cart-button-header-cart, #secondline-checkout-basket a.checkout-button-header-cart, #secondline-checkout-basket a:hover, #secondline-checkout-basket ul#secondline-cart-small li h6, #secondline-checkout-basket .secondline-sub-total span.total-number-add, .sf-menu li.sfHover li a:hover, .sf-menu li.sfHover li.sfHover a, .sf-menu li.sfHover li li a:hover, .sf-menu li.sfHover li.sfHover li.sfHover a, .sf-menu li.sfHover li li li a:hover, .sf-menu li.sfHover li.sfHover li.sfHover a:hover, .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover a, .sf-menu li.sfHover li li li li a:hover, .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover a:hover, .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover a, .sf-menu li.sfHover li li li li li a:hover, .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover a:hover, .sf-menu li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover li.sfHover a {
		color:". esc_attr( get_theme_mod('secondline_themes_sub_nav_hover_font_color', '#ffffff') ) . ";
	}

	.secondline_themes_force_dark_navigation_color .secondline-fixed-scrolled #secondline-shopping-cart-count span.secondline-cart-count,
	.secondline_themes_force_light_navigation_color .secondline-fixed-scrolled #secondline-shopping-cart-count span.secondline-cart-count,
	#secondline-shopping-cart-count span.secondline-cart-count {
		background:" . esc_attr( get_theme_mod('secondline_themes_nav_cart_background', '#ffffff') ) . ";
		color:" . esc_attr( get_theme_mod('secondline_themes_nav_cart_color', '#0a0715') ) . ";
	}
	.secondline-fixed-scrolled .sf-menu .secondline-mini-banner-icon,
	.secondline-mini-banner-icon {
		color:#ffffff;
	}
	.secondline-mini-banner-icon {
		top:" . esc_attr( (get_theme_mod('secondline_themes_nav_padding', '35') - get_theme_mod('secondline_themes_nav_font_size', '15')) - 4 ). "px;
		right:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') / 2 ) . "px;
	}


	.secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.current-menu-item.highlight-button a:hover:before, .secondline_themes_force_light_navigation_color .secondline-fixed-scrolled .sf-menu li.highlight-button a:hover:before, .sf-menu li.current-menu-item.highlight-button a:hover:before, .sf-menu li.highlight-button a:hover:before {
		width:100%;
	}

	#secondline-checkout-basket ul#secondline-cart-small li, #secondline-checkout-basket .secondline-sub-total, #panel-search-secondline .search-form input.search-field, .sf-mega li:last-child li a, body header .sf-mega li:last-child li a, .sf-menu li li a, .sf-mega h2.mega-menu-heading, .sf-mega ul, body .sf-mega ul, #secondline-checkout-basket .secondline-sub-total, #secondline-checkout-basket ul#secondline-cart-small li {
		border-color:" . esc_attr( get_theme_mod('secondline_themes_sub_nav_border_color', '#444444') ) . ";
	}

	#secondline-inline-icons .secondline-themes-social-icons a {
		padding-left:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') -  7 ). "px;
		padding-right:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') - 7 ). "px;
	}
	#secondline-themes-header-search-icon i.pe-7s-search {
		padding-left:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') ). "px;
		padding-right:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') ). "px;
	}
	#secondline-inline-icons .secondline-themes-social-icons {
		padding-right:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') - 7 ). "px;
	}
	.sf-menu a {
		padding-left:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') ). "px;
		padding-right:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') ). "px;
	}

	.sf-menu li.highlight-button {
		margin-right:". esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') - 7 ) . "px;
		margin-left:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') - 7 ) . "px;
	}
	.sf-arrows .sf-with-ul {
		padding-right:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') + 15 ) . "px;
	}
	.sf-arrows .sf-with-ul:after {
		right:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') + 9 ) . "px;
	}

	.rtl .sf-arrows .sf-with-ul {
		padding-right:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') ) . "px;
		padding-left:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') + 15 ) . "px;
	}
	.rtl  .sf-arrows .sf-with-ul:after {
		right:auto;
		left:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') + 9 ) . "px;
	}

	@media only screen and (min-width: 960px) and (max-width: 1300px) {
		#page-title-slt-post-page, #page-title-slt-post-page .secondline-themes-gallery .blog-single-gallery-post-format { height:" . esc_attr( get_theme_mod('secondline_themes_blog_post_height', '600') - 50 ) . "px; }
		nav#secondline-themes-right-navigation ul li a {
			padding-left:16px;
			padding-right:16px;
		}
		#post-secondary-page-title-slt, #page-title-slt {
			padding-top:" . esc_attr( get_theme_mod('secondline_themes_page_title_padding_top', '184') - 10 ). "px;
			padding-bottom:" . esc_attr( get_theme_mod('secondline_themes_page_title_padding_bottom', '130') - 10 ). "px;
		}
		.sf-menu a {
			padding-left:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') - 4 ). "px;
			padding-right:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') - 4 ). "px;
		}
		.sf-menu li.highlight-button {
			margin-right:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') - 12 ). "px;
			margin-left:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') - 12 ). "px;
		}
		.sf-arrows .sf-with-ul {
			padding-right:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') + 13 ). "px;
		}
		.sf-arrows .sf-with-ul:after {
			right:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') + 7 ). "px;
		}
		.rtl .sf-arrows .sf-with-ul {
			padding-left:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18')  ). "px;
			padding-left:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') + 13 ). "px;
		}
		.rtl .sf-arrows .sf-with-ul:after {
			right:auto;
			left:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') + 7 ). "px;
		}
		#secondline-inline-icons .secondline-themes-social-icons a {
			padding-left:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') -  12 ). "px;
			padding-right:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') - 12 ). "px;
		}
		#secondline-themes-header-search-icon i.pe-7s-search {
			padding-left:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') - 4). "px;
			padding-right:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') - 4). "px;
		}
		#secondline-inline-icons .secondline-themes-social-icons {
			padding-right:" . esc_attr( get_theme_mod('secondline_themes_nav_left_right', '18') - 12 ). "px;
		}
	}

	$secondline_themes_optiona_nav_bg_hover
	$secondline_themes_optiona_fixed_nav_font_bg
	$secondline_themes_optiona_fixed_nav_hover_bg
	$secondline_themes_option_fixed_nav_font_color
	$secondline_themes_option_stickY_nav_font_hover_color
	$secondline_themes_option_fixed_hightlight_bg_color
	$secondline_themes_option_fixed_hightlight_font_color
	$secondline_themes_option_fixed_hightlight_bg_color_hover
	/* END Main Navigation Customizer Styles */
	header .secondline-themes-social-icons a, header #secondline-inline-icons .secondline-themes-social-icons a {
		color:" . esc_attr( get_theme_mod('secondline_themes_header_icon_color', '#2d2d2d') ) . ";
	}

	/* START FOOTER STYLES */
	footer#site-footer {
		background: " . esc_attr(get_theme_mod('secondline_themes_footer_background', '#f9f9f9')) . ";
		$secondline_themes_footer_bg_image
		$secondline_themes_main_image_position_cover
	}
	footer#site-footer #secondline-themes-copyright a {  color: " . esc_attr(get_theme_mod('secondline_themes_copyright_link', '#333333')) . ";}
	footer#site-footer #secondline-themes-copyright a:hover { color: " . esc_attr(get_theme_mod('secondline_themes_copyright_link_hover', '#ff4102')) . "; }
	#secondline-themes-copyright {
		$secondline_themes_copyright_optional_bg
	}
	#secondline-themes-lower-widget-container .widget, #widget-area-secondline .widget { padding:" . esc_attr(get_theme_mod('secondline_themes_widgets_margin_top', '65')) . "px 0px " . esc_attr(get_theme_mod('secondline_themes_widgets_margin_bottom', '40')) . "px 0px; }
	#copyright-text { padding:" . esc_attr(get_theme_mod('secondline_themes_copyright_margin_top', '18')) . "px 0px " . esc_attr(get_theme_mod('secondline_themes_copyright_margin_bottom', '13')) . "px 0px; }
	footer#site-footer .secondline-themes-social-icons {
		padding-top:" . esc_attr(get_theme_mod('secondline_themes_footer_margin_top', '0')) . "px;
		padding-bottom:" . esc_attr(get_theme_mod('secondline_themes_footer_margin_bottom', '0')) . "px;
	}
	footer#site-footer ul.secondline-themes-social-widget li a , footer#site-footer #secondline-themes-copyright .secondline-themes-social-icons a, footer#site-footer .secondline-themes-social-icons a {
		color:" . esc_attr(get_theme_mod('secondline_themes_footer_icon_color', '#ffffff')) . ";
	}
	.sidebar ul.secondline-themes-social-widget li a, footer#site-footer ul.secondline-themes-social-widget li a, footer#site-footer .secondline-themes-social-icons a {
		background:" . esc_attr(get_theme_mod('secondline_themes_footer_icon_border_color', '#2d2d2d')) . ";
	}
	footer#site-footer ul.secondline-themes-social-widget li a:hover, footer#site-footer #secondline-themes-copyright .secondline-themes-social-icons a:hover, footer#site-footer .secondline-themes-social-icons a:hover {
		color:" . esc_attr(get_theme_mod('secondline_themes_footer_hover_icon_color', '#ffffff')) . ";
	}
	.sidebar ul.secondline-themes-social-widget li a:hover, footer#site-footer ul.secondline-themes-social-widget li a:hover, footer#site-footer .secondline-themes-social-icons a:hover {
		background:" . esc_attr(get_theme_mod('secondline_themes_footer_hover_background_icon_color', '#555555')) . ";
	}
	footer#site-footer .secondline-themes-social-icons li a {
		margin-right:" . esc_attr(get_theme_mod('secondline_themes_footer_margin_sides', '5')) . "px;
		margin-left:" . esc_attr(get_theme_mod('secondline_themes_footer_margin_sides', '5')) . "px;
	}
	footer#site-footer .secondline-themes-social-icons a, footer#site-footer #secondline-themes-copyright .secondline-themes-social-icons a {
		font-size:" . esc_attr(get_theme_mod('secondline_themes_footer_icon_size', '12')) . "px;
        width:" . esc_attr(get_theme_mod('secondline_themes_footer_icon_size', '12')) . "px;
        height:" . esc_attr(get_theme_mod('secondline_themes_footer_icon_size', '12')) . "px;
        line-height:" . esc_attr(get_theme_mod('secondline_themes_footer_icon_size', '12')) . "px;
	}
	#secondline-themes-footer-logo { max-width:" . esc_attr( get_theme_mod('secondline_themes_footer_logo_width', '250') ) . "px; padding-top:" . esc_attr( get_theme_mod('secondline_themes_footer_logo_margin_top', '45') ) . "px; padding-bottom:" . esc_attr( get_theme_mod('secondline_themes_footer_logo_margin_bottom', '0') ) . "px; padding-right:" . esc_attr( get_theme_mod('secondline_themes_footer_logo_margin_right', '0') ) . "px; padding-left:" . esc_attr( get_theme_mod('secondline_themes_footer_logo_margin_left', '0') ) . "px; }
	/* END FOOTER STYLES */
	@media only screen and (max-width: 959px) {

		#page-title-slt-post-page, #page-title-slt-post-page .secondline-themes-gallery .blog-single-gallery-post-format { height:" . esc_attr( get_theme_mod('secondline_themes_blog_post_height', '600') - 100 ) . "px; }

		#post-secondary-page-title-slt, #page-title-slt {
			padding-top:" . esc_attr( get_theme_mod('secondline_themes_page_title_padding_top', '184') - 30 ). "px;
			padding-bottom:" . esc_attr( get_theme_mod('secondline_themes_page_title_padding_bottom', '130') - 30 ). "px;
		}
		.secondline-themes-transparent-header header#masthead-slt {
			$secondline_themes_header_bg_image
			$secondline_themes_header_bg_cover
		}
		$secondline_themes_mobile_header_bg_color
		$secondline_themes_mobile_header_logo_width
		$secondline_themes_mobile_header_logo_margin_top
		$secondline_themes_mobile_header_nav_padding_top
	}
	@media only screen and (max-width: 959px) {
		#secondline-themes-lower-widget-container .widget, #widget-area-secondline .widget { padding:" . esc_attr(get_theme_mod('secondline_themes_widgets_margin_top', '65') - 10 ) . "px 0px " . esc_attr(get_theme_mod('secondline_themes_widgets_margin_bottom', '40') - 10 ) . "px 0px; }
	}
	@media only screen and (min-width: 960px) and (max-width: ". esc_attr( get_theme_mod('secondline_themes_site_width', '1400') + 100 ) . "px) {
		.width-container-slt {
			width:92%;
			position:relative;
			padding:0px;
		}


		footer#site-footer.secondline-themes-footer-full-width .width-container-slt,
		.secondline-themes-page-title-full-width #page-title-slt .width-container-slt,
		.secondline-themes-header-full-width header#masthead-slt .width-container-slt {
			width:92%;
			position:relative;
			padding:0px;
		}
		.secondline-themes-header-full-width-no-gap.secondline-themes-header-cart-width-adjustment header#masthead-slt .width-container-slt,
		.secondline-themes-header-full-width.secondline-themes-header-cart-width-adjustment header#masthead-slt .width-container-slt {
			width:98%;
			margin-left:2%;
			padding-right:0;
		}
		#secondline-shopping-cart-toggle.activated-class a i.shopping-cart-header-icon,
		#secondline-shopping-cart-count i.shopping-cart-header-icon {
			padding-left:24px;
			padding-right:24px;
		}
		#secondline-shopping-cart-count span.secondline-cart-count {
			right:14px;
		}
		header .sf-mega {
			margin-right:2%;
			width:98%;
			left:0px;
			margin-left:auto;
		}
	}
	$secondline_themes_boxed_layout
	::-moz-selection {color:" . esc_attr( get_theme_mod('secondline_themes_select_color', '#ffffff') ) . ";background:" . esc_attr( get_theme_mod('secondline_themes_select_bg', '#2d2d2d') ) . ";}
	::selection {color:" . esc_attr( get_theme_mod('secondline_themes_select_color', '#ffffff') ) . ";background:" . esc_attr( get_theme_mod('secondline_themes_select_bg', '#2d2d2d') ) . ";}
	";
        wp_add_inline_style( 'secondline-themes-custom-style', $secondline_themes_custom_css );
}
add_action( 'wp_enqueue_scripts', 'secondline_themes_customizer_styles' );
